@@ -278,6 +278,31 @@ class VolumeMappings:
         return self.mappings.__iter__()
 
 
+@dataclasses.dataclass
+class ContainerConfiguration:
+    image_name: str
+    name: Optional[str] = None
+    volumes: Optional[VolumeMappings] = None
+    ports: Optional[PortMappings] = None
+    entrypoint: Optional[str] = None
+    additional_flags: Optional[List[str]] = None
+    command: Optional[List[str]] = None
+    env_vars: Dict[str, str] = dataclasses.field(default_factory=dict)
+
+    privileged: Optional[bool] = None
+    remove: Optional[bool] = None
+    interactive: Optional[bool] = None
+    tty: Optional[bool] = None
+    detach: Optional[bool] = None
+
+    stdin: Optional[str] = None
+    user: Optional[str] = None
+    cap_add: Optional[str] = None
+    network: Optional[str] = None
+    dns: Optional[str] = None
+    workdir: Optional[str] = None
+
+
 class ContainerClient(metaclass=ABCMeta):
     STOP_TIMEOUT = 0
 
@@ -431,14 +456,14 @@ class ContainerClient(metaclass=ABCMeta):
         """
         pass
 
-    def get_image_cmd(self, docker_image: str, pull: bool = True) -> str:
+    def get_image_cmd(self, docker_image: str, pull: bool = True) -> List[str]:
         """Get the command for the given image
         :param docker_image: Docker image to inspect
         :param pull: Whether to pull if image is not present
-        :return: Image command
+        :return: Image command in its array form
         """
         cmd_list = self.inspect_image(docker_image, pull)["Config"]["Cmd"] or []
-        return " ".join(cmd_list)
+        return cmd_list
 
     def get_image_entrypoint(self, docker_image: str, pull: bool = True) -> str:
         """Get the entry point for the given image
@@ -448,7 +473,7 @@ class ContainerClient(metaclass=ABCMeta):
         """
         LOG.debug("Getting the entrypoint for image: %s", docker_image)
         entrypoint_list = self.inspect_image(docker_image, pull)["Config"]["Entrypoint"] or []
-        return " ".join(entrypoint_list)
+        return shlex.join(entrypoint_list)
 
     @abstractmethod
     def has_docker(self) -> bool:
